@@ -28,7 +28,7 @@ from pulpcore.plugin.serializers import (
     RepositorySyncURLSerializer,
 )
 from pulpcore.plugin.models import Artifact, Content
-from pulpcore.plugin.tasking import dispatch
+from pulpcore.plugin.tasking import dispatch, general_multi_delete
 from pulpcore.plugin.viewsets import (
     AsyncUpdateMixin,
     DistributionViewSet,
@@ -161,20 +161,16 @@ class ContainerContentQuerySetMixin:
             if "repository_version" in key:
                 rv = view.get_resource(param, RepositoryVersion)
                 repo = rv.repository.cast()
-                if (
-                    request.user.has_perm(repo_info.push_perm)
-                    and repo.pulp_type == repo_info.push_type
-                ):
-                    repo_pks.append(repo.pk)
-                elif (
-                    request.user.has_perm(repo_info.mirror_perm)
-                    and repo.pulp_type == repo_info.mirror_type
-                ):
-                    repo_pks.append(repo.pk)
-                elif request.user.has_perm(repo_info.push_perm, repo) or request.user.has_perm(
-                    repo_info.mirror_perm, repo
-                ):
-                    repo_pks.append(repo.pk)
+                if repo.pulp_type == repo_info.push_type:
+                    if request.user.has_perm(repo_info.push_perm) or request.user.has_perm(
+                        repo_info.push_perm, repo
+                    ):
+                        repo_pks.append(repo.pk)
+                elif repo.pulp_type == repo_info.mirror_type:
+                    if request.user.has_perm(repo_info.mirror_perm) or request.user.has_perm(
+                        repo_info.mirror_perm, repo
+                    ):
+                        repo_pks.append(repo.pk)
         return repo_pks
 
     def get_queryset(self):
@@ -1222,7 +1218,7 @@ class ContainerDistributionViewSet(DistributionViewSet):
             )
 
         async_result = dispatch(
-            tasks.general_multi_delete, exclusive_resources=reservations, args=(instance_ids,)
+            general_multi_delete, exclusive_resources=reservations, args=(instance_ids,)
         )
         return OperationPostponedResponse(async_result, request)
 
@@ -1392,6 +1388,6 @@ class ContainerNamespaceViewSet(
             (str(namespace.pk), "container", "ContainerNamespaceSerializer"),
         )
         async_result = dispatch(
-            tasks.general_multi_delete, exclusive_resources=reservations, args=(instance_ids,)
+            general_multi_delete, exclusive_resources=reservations, args=(instance_ids,)
         )
         return OperationPostponedResponse(async_result, request)
